uim.codec API documentation
Description: Codec parser.

# Module `uim.codec`

Codec parser.

Expand source code

    # -*- coding: utf-8 -*-
    """
    Codec parser.
    """
    __all__ = ['context', 'parser', 'writer']

    from uim.codec import context
    from uim.codec import parser
    from uim.codec import writer

## Sub-modules

`uim.codec.base`
`uim.codec.context`

  Context

  This package contains structures to handle the encoding a decoding context, with information such as: …

`uim.codec.format`
`uim.codec.parser`

  Parser

  This package contains different parsers for ink formats: …

`uim.codec.writer`

  Writer

  This package contains different encoders for ink formats: …